# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-05-09 16:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0044_reporting_config_multiple_types'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomerreportingconfiguration',
            name='report_type',
            field=models.CharField(choices=[('csv', 'csv'), ('json', 'json')], default='csv', help_text='The type this report should be sent as, e.g. CSV.', max_length=20, verbose_name='Report Type'),
        ),
    ]



# -*- coding: utf-8 -*-

"""
xAPI statement for learner course enrollment.
"""
from __future__ import absolute_import, unicode_literals

from tincan import LanguageMap, Verb

from integrated_channels.xapi.constants import X_API_VERB_REGISTERED
from integrated_channels.xapi.statements.base import EnterpriseStatement


class LearnerCourseEnrollmentStatement(EnterpriseStatement):
    """
    xAPI statement to serialize data related to course registration.
    """

    def __init__(self, user, course_overview, user_details, course_details, *args, **kwargs):
        """
        Initialize and populate statement with learner info and course info.

        Arguments:
            user (User): Auth User object containing information about the learner enrolling in the course.
            course_overview (CourseOverview): course overview object containing course details.
            user_details (dict): A dict object containing learner info we want to send in xAPI statement payload.
            course_details (dict): A dict object containing course info we want to send in xAPI statement payload.
        """
        kwargs.update(
            actor=self.get_actor(user.username, user.email),
            verb=self.get_verb(),
            object=self.get_object(course_overview.display_name, course_overview.short_description),
            context=self.get_context(user_details, course_details)
        )
        super(LearnerCourseEnrollmentStatement, self).__init__(*args, **kwargs)

    def get_verb(self):
        """
        Get verb for course enrollment statement.
        """
        return Verb(
            id=X_API_VERB_REGISTERED,
            display=LanguageMap({'en-US': 'registered'}),
        )



# -*- coding: utf-8 -*-
"""
URL definitions for enterprise api version 1 endpoint.
"""
from __future__ import absolute_import, unicode_literals

from rest_framework.routers import DefaultRouter

from django.conf.urls import url

from enterprise.api.v1 import views

router = DefaultRouter()  # pylint: disable=invalid-name
router.register("enterprise_catalogs", views.EnterpriseCustomerCatalogViewSet, 'enterprise-catalogs')
router.register("enterprise-course-enrollment", views.EnterpriseCourseEnrollmentViewSet, 'enterprise-course-enrollment')
router.register("enterprise-customer", views.EnterpriseCustomerViewSet, 'enterprise-customer')
router.register("enterprise-learner", views.EnterpriseCustomerUserViewSet, 'enterprise-learner')
router.register(
    "enterprise-customer-branding",
    views.EnterpriseCustomerBrandingConfigurationViewSet,
    'enterprise-customer-branding',
)
router.register(
    "enterprise-customer-entitlement",
    views.EnterpriseCustomerEntitlementViewSet,
    'enterprise-customer-entitlement',
)
router.register(
    "enterprise_customer_reporting",
    views.EnterpriseCustomerReportingConfigurationViewSet,
    'enterprise-customer-reporting',
)

urlpatterns = [
    url(
        r'^enterprise_catalog_query/(?P<catalog_query_id>[\d]+)/$',
        views.CatalogQueryView.as_view(),
        name='enterprise-catalog-query'
    ),
    url(
        r'^request_codes$',
        views.CouponCodesView.as_view(),
        name='request-codes'
    ),
]

urlpatterns += router.urls
